function RUNME

is_ml = is_matlab;

repeat = 10;

if( is_matlab )
   ns = unique(ceil(exp(log(2):0.2:log(100000))));
else
   load('examples.mat');
end

max_time = 1.0;

maxrelerr = 1e-5;

time_abgabe  = zeros(1, length(ns));
time_ref     = zeros(1, length(ns));
time_matlab  = zeros(1, length(ns));
err_abgabe   = zeros(1, length(ns));
max_err      = zeros(1, length(ns));

act_pos = 0;

disp('Vergleiche Geschwindigkeiten');
fprintf('\n');

count = 0;

splits = 10;

for i=3:length(ns)
   act_pos = act_pos+1;

   n = ns(i);

   fprintf('%d|', n);
   count = count+1;
   if( count>15 )
      fprintf('\n');
      count = 0;
   end

   sumtime_abgabe = 0;
   sumtime_ref    = 0;
   sumtime_matlab = 0;
   sumerr_abgabe  = 0;
   summax_err     = 0;

   for j=1:repeat
      if( is_ml )
         x = sort(randn(n, 1));
         f = randn(n, 1);

         interval = linspace(min(x), max(x), n*3);
      else
         x = x_cell{i};
         f = f_cell{i};

         interval = interval_cell{i};
      end

      % run Abgabe
      tic;
      abgabe_spline = berechne_spline(x, f);
      abgabe_yy = spline_auswerten(abgabe_spline, interval);
      sumtime_abgabe = sumtime_abgabe + toc;

      % run Referenz
      tic;
      if( is_ml )
         reference_spline = ref_berechne_spline(x, f);
         reference_yy = ref_spline_auswerten(reference_spline, interval);
      else
         reference_spline = spline_cell{i};
         reference_yy = sol_cell{i};
      end
      sumtime_ref = sumtime_ref + toc;

      % run Matlab
      tic;
      pp = spline(x, f);
      matlab_yy = ppval(pp, interval);
      sumtime_matlab = sumtime_matlab + toc;

      maxerr = n*1000000*eps;

      realerr = norm(abgabe_yy - reference_yy);

      if( realerr > maxerr )
         realerr
         maxerr
         error('Fehler in der Abgabe!');
      end

      sumerr_abgabe = sumerr_abgabe + realerr;
      summax_err = summax_err + maxerr;
   end

%         plot(all_x(1:to), all_f(1:to), 'bx');
%         hold on;
%         plot(interval, y_abgabe, 'r-');
%         hold off;
%         waitforbuttonpress;

   time_abgabe(i)   = sumtime_abgabe/repeat;
   time_ref(i)      = sumtime_ref/repeat;
   time_matlab(i)   = sumtime_matlab/repeat;
   err_abgabe(i)    = sumerr_abgabe/repeat;
   max_err(i)       = summax_err/repeat;

   if( (sumtime_abgabe+sumtime_ref+sumtime_matlab)>max_time )
      break;
   end
end

fprintf('\n');

time_abgabe   = time_abgabe(1:act_pos);
time_ref      = time_ref(1:act_pos);
time_matlab   = time_matlab(1:act_pos);
err_abgabe    = err_abgabe(1:act_pos);
err_abgabe( err_abgabe<=0 ) = eps;
max_err       = max_err(1:act_pos);
ns = ns(1:act_pos);

subplot(2,1,1);
if( is_ml )
   loglog(ns, time_abgabe, 'b-', ns, time_ref, 'r--', ns, time_matlab, 'k-.');
else
   loglog(ns, time_abgabe, 'b-', ns, time_matlab, 'k-.');
end
title('Spline Interpolation');
xlabel('n = Anzahl der Stuetzpunkte');
ylabel('Laufzeit');
if( is_ml )
   legend('Abgabe', 'Referenz', 'Matlab', 'Location', 'NorthWest');
else
   legend('Abgabe', 'Matlab', 'Location', 'NorthWest');
end

subplot(2,1,2);

loglog(ns, err_abgabe, 'b-' );
hold on;
loglog(ns, max_err, 'r-' )
xlabel('n = Anzahl der Knotenpunkte');
ylabel('Fehler')
legend('|| y_{abgabe} - y_{ref} ||', 'Maximal erlaubter Fehler', 'Location', 'NorthWest');

hold off;

